@@ -6,12 +6,22 @@
 # as UTF-8 encoded.
 #
 
-$:.unshift(File.dirname(__FILE__))
+if Kernel.respond_to?(:require_relative)
+  require_relative("test_helper")
+else
+  $:.unshift(File.dirname(__FILE__))
+  require 'test_helper'
+end
+
 #
 # Test Ruby 1.8 with $KCODE='U'
 #
-require 'test_helper'
-#
+
+=begin
+
+  Main class for testing Stomp::Message.
+
+=end
 class TestMessage < Test::Unit::TestCase
   include TestBase
   #
@@ -87,7 +97,7 @@ class TestMessage < Test::Unit::TestCase
 		end
   end
 
-	#
+	# Test various valid and invalid frames.
 	def test_0040_msg_create
 		#
 		assert_raise(Stomp::Error::InvalidFormat) {
@@ -132,7 +142,7 @@ class TestMessage < Test::Unit::TestCase
 
 	end
 
-	# Multiple headers with the same key
+	# Test multiple headers with the same key
 	def test_0050_mh_msg_create
     aframe = bframe = nil
 		assert_nothing_raised {
